#
# spec file for package ghc-unliftio
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global pkg_name unliftio
%global pkgver %{pkg_name}-%{version}
%bcond_with tests
Name:           ghc-%{pkg_name}
Version:        0.2.25.0
Release:        1.21
Summary:        The MonadUnliftIO typeclass for unlifting monads to IO (batteries included)
License:        MIT
URL:            https://hackage.haskell.org/package/%{pkg_name}
Source0:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/%{pkg_name}-%{version}.tar.gz
BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-async-devel
BuildRequires:  ghc-async-prof
BuildRequires:  ghc-base-devel
BuildRequires:  ghc-base-prof
BuildRequires:  ghc-bytestring-devel
BuildRequires:  ghc-bytestring-prof
BuildRequires:  ghc-deepseq-devel
BuildRequires:  ghc-deepseq-prof
BuildRequires:  ghc-directory-devel
BuildRequires:  ghc-directory-prof
BuildRequires:  ghc-filepath-devel
BuildRequires:  ghc-filepath-prof
BuildRequires:  ghc-process-devel
BuildRequires:  ghc-process-prof
BuildRequires:  ghc-rpm-macros
BuildRequires:  ghc-safe-exceptions-devel
BuildRequires:  ghc-safe-exceptions-prof
BuildRequires:  ghc-stm-devel
BuildRequires:  ghc-stm-prof
BuildRequires:  ghc-time-devel
BuildRequires:  ghc-time-prof
BuildRequires:  ghc-transformers-devel
BuildRequires:  ghc-transformers-prof
BuildRequires:  ghc-unix-devel
BuildRequires:  ghc-unix-prof
BuildRequires:  ghc-unliftio-core-devel
BuildRequires:  ghc-unliftio-core-prof
ExcludeArch:    %{ix86}
%if %{with tests}
BuildRequires:  ghc-QuickCheck-devel
BuildRequires:  ghc-QuickCheck-prof
BuildRequires:  ghc-containers-devel
BuildRequires:  ghc-containers-prof
BuildRequires:  ghc-hspec-devel
BuildRequires:  ghc-hspec-prof
%endif

%description
Please see the documentation and README at
<https://www.stackage.org/package/unliftio>.

%package devel
Summary:        Haskell %{pkg_name} library development files
Requires:       %{name} = %{version}-%{release}
Requires:       ghc-compiler = %{ghc_version}
Requires(post): ghc-compiler = %{ghc_version}
Requires(postun): ghc-compiler = %{ghc_version}

%description devel
This package provides the Haskell %{pkg_name} library development files.

%package -n ghc-%{pkg_name}-doc
Summary:        Haskell %{pkg_name} library documentation
Requires:       ghc-filesystem
BuildArch:      noarch

%description -n ghc-%{pkg_name}-doc
This package provides the Haskell %{pkg_name} library documentation.

%package -n ghc-%{pkg_name}-prof
Summary:        Haskell %{pkg_name} profiling library
Requires:       ghc-%{pkg_name}-devel = %{version}-%{release}
Supplements:    (ghc-%{pkg_name}-devel and ghc-prof)

%description -n ghc-%{pkg_name}-prof
This package provides the Haskell %{pkg_name} profiling library.

%prep
%autosetup -n %{pkg_name}-%{version}

%build
%ghc_lib_build

%install
%ghc_lib_install

%check
%cabal_test

%post devel
%ghc_pkg_recache

%postun devel
%ghc_pkg_recache

%files -f %{name}.files
%license LICENSE

%files devel -f %{name}-devel.files
%doc ChangeLog.md README.md

%files -n ghc-%{pkg_name}-doc -f ghc-%{pkg_name}-doc.files
%license LICENSE

%files -n ghc-%{pkg_name}-prof -f ghc-%{pkg_name}-prof.files

%changelog
* Fri Jun 16 2023 Peter Simons <psimons@suse.com>
- Update unliftio to version 0.2.25.0.
  [#]# 0.2.25.0
  * Add `UnliftIO.Exception.Lens`
* Thu Mar 30 2023 Peter Simons <psimons@suse.com>
- Updated spec file to conform with ghc-rpm-macros-2.5.2.
* Tue Feb 28 2023 Peter Simons <psimons@suse.com>
- Update unliftio to version 0.2.24.0.
  [#]# 0.2.24.0
  * Add `UnliftIO.STM.writeTMVar`
  * Add `UnliftIO.STM.stateTVar`
* Thu Oct 27 2022 Peter Simons <psimons@suse.com>
- Update unliftio to version 0.2.23.0.
  [#]# 0.2.23.0
  * `UnliftIO.Exception` re-exports the `Handler` and sync/async exception wrappers
    from `safe-exceptions`, instead of redefining them.
  * With this change, you won't be able to distinguish between an asynchronous
    exception from `UnliftIO.Exception.throwTo` and `Control.Exception.Safe.throwTo`.
  * [#103](https://github.com/fpco/unliftio/pull/103)
* Tue Apr 26 2022 Peter Simons <psimons@suse.com>
- Update unliftio to version 0.2.22.0.
  [#]# 0.2.22.0
  * Add `UnliftIO.STM.flushTBQueue`
  * Add `UnliftIO.STM.lengthTBQueue`
* Wed Feb  9 2022 Peter Simons <psimons@suse.com>
- Update unliftio to version 0.2.21.0.
  [#]# 0.2.21.0
  * Add `UnliftIO.Directory.createDirectoryLink`
  * Add `UnliftIO.Directory.removeDirectoryLink`
  * Add `UnliftIO.Directory.getSymbolicLinkTarget`
  * Add `UnliftIO.Directory.XdgDirectoryList`
  * Add `UnliftIO.Directory.getXdgDirectoryList`
  [#]# 0.2.20.1
  * Fix time-osx.c for aarch64 mac [#91](https://github.com/fpco/unliftio/pull/91)
* Thu Sep  2 2021 psimons@suse.com
- Update unliftio to version 0.2.20.
  [#]# 0.2.20
  * Add lifted `System.IO.openFile` (https://github.com/fpco/unliftio/pull/88)
* Fri Jul 23 2021 psimons@suse.com
- Update unliftio to version 0.2.19.
  [#]# 0.2.19
  * Add `Eq` instance for `StringException` (https://github.com/fpco/unliftio/pull/83)
* Wed Jun  2 2021 psimons@suse.com
- Update unliftio to version 0.2.18.
  [#]# 0.2.18
  * Reexport `asyncExceptionFromException` and `asyncExceptionToException` [#81](https://github.com/fpco/unliftio/issues/81)
* Sat May 29 2021 psimons@suse.com
- Update unliftio to version 0.2.17.
  [#]# 0.2.17
  * Re-export `AsyncCancelled` in `UnliftIO.Async` [#80](https://github.com/fpco/unliftio/pull/80)
  * Add `fromExceptionUnwrap` [#80](https://github.com/fpco/unliftio/pull/80)
  * Add `catchSyncOrAsync`, `handleSyncOrAsync`, and `trySyncOrAsync` [#80](https://github.com/fpco/unliftio/pull/80)
* Mon May 10 2021 psimons@suse.com
- Update unliftio to version 0.2.16.
  [#]# 0.2.16
  * Add `createFileLink`
* Fri May  7 2021 psimons@suse.com
- Update unliftio to version 0.2.15.
  [#]# 0.2.15
  * Updated documentation mentioning that `MonadUnliftIO` may be derived using
    the `newtype` strategy [#72](https://github.com/fpco/unliftio/pull/72)
  * Add `mapExceptionM` [#75](https://github.com/fpco/unliftio/pull/75)
* Sun Jan 24 2021 psimons@suse.com
- Update unliftio to version 0.2.14.
  [#]# 0.2.14
  * Add `UnliftIO.QSem`
  * Add `UnliftIO.QSemN`
* Thu Dec 17 2020 Ondřej Súkup <mimi.vx@gmail.com>
- disable %%{ix86} build
* Fri Oct 30 2020 psimons@suse.com
- Update unliftio to version 0.2.13.1.
  [#]# 0.2.13.1
  * Improve `UnliftIO.Exception` documentation
* Tue Aug 18 2020 Peter Simons <psimons@suse.com>
- Replace %%setup -q with the more modern %%autosetup macro.
* Tue Jun  9 2020 psimons@suse.com
- Add unliftio at version 0.2.13.
